@@ -1,29 +1,29 @@
 """Representation of an automation configured in Abode."""
 import logging
 
-from .exceptions import AbodeException
+import jaraco
 
-from .helpers import constants as CONST
+from .helpers import urls
 from .helpers import errors as ERROR
 
 _LOGGER = logging.getLogger(__name__)
 
 
-class AbodeAutomation:
+class Automation:
     """Class for viewing and controlling automations."""
 
     def __init__(self, abode, automation):
-        """Init AbodeAutomation class."""
-        self._abode = abode
+        """Init Automation class."""
+        self._client = abode
         self._automation = automation
 
     def enable(self, enable):
         """Enable or disable the automation."""
-        path = CONST.AUTOMATION_ID_URL.format(id=self.automation_id)
+        path = urls.AUTOMATION_ID.format(id=self.automation_id)
 
         self._automation['enabled'] = enable
 
-        response = self._abode.send_request(
+        response = self._client.send_request(
             method="patch", path=path, data={'enabled': enable}
         )
 
@@ -35,7 +35,7 @@ class AbodeAutomation:
         if str(response_object['id']) != str(self._automation['id']) or str(
             response_object['enabled']
         ) != str(self._automation['enabled']):
-            raise AbodeException(ERROR.INVALID_AUTOMATION_EDIT_RESPONSE)
+            raise jaraco.abode.Exception(ERROR.INVALID_AUTOMATION_EDIT_RESPONSE)
 
         self.update(response_object)
 
@@ -44,24 +44,24 @@ class AbodeAutomation:
 
     def trigger(self):
         """Trigger the automation."""
-        path = CONST.AUTOMATION_APPLY_URL.format(id=self.automation_id)
+        path = urls.AUTOMATION_APPLY.format(id=self.automation_id)
 
-        self._abode.send_request(method="post", path=path)
+        self._client.send_request(method="post", path=path)
 
         _LOGGER.info("Automation triggered: %s", self.name)
 
     def refresh(self):
         """Refresh the automation."""
-        path = CONST.AUTOMATION_ID_URL.format(id=self.automation_id)
+        path = urls.AUTOMATION_ID.format(id=self.automation_id)
 
-        response = self._abode.send_request(method="get", path=path)
+        response = self._client.send_request(method="get", path=path)
         response_object = response.json()
 
         if isinstance(response_object, (tuple, list)):
             response_object = response_object[0]
 
         if str(response_object['id']) != self.automation_id:
-            raise AbodeException(ERROR.INVALID_AUTOMATION_REFRESH_RESPONSE)
+            raise jaraco.abode.Exception(ERROR.INVALID_AUTOMATION_REFRESH_RESPONSE)
 
         self.update(response_object)
 
