@@ -1,12 +1,14 @@
 """Abode cover device."""
 
-from ..devices.switch import AbodeSwitch
 from ..helpers import constants as CONST
+from .switch import Switch
 
 
-class AbodeCover(AbodeSwitch):
+class Cover(Switch):
     """Class to add cover functionality."""
 
+    implements = CONST.TYPE_COVER
+
     def switch_on(self):
         """Turn the switch on."""
         success = self.set_status(CONST.STATUS_OPEN_INT)
