@@ -1,11 +1,12 @@
+import builtins
 import requests
 
 
-class AbodeException(Exception):
+class Exception(builtins.Exception):
     """Class to throw general abode exception."""
 
     def __init__(self, error, details=None):
-        """Initialize AbodeException."""
+        """Initialize Exception."""
         # Call the base class constructor with the parameters it needs
         super().__init__(error[1])
 
@@ -14,7 +15,7 @@ class AbodeException(Exception):
         self.details = details
 
 
-class AbodeAuthenticationException(AbodeException):
+class AuthenticationException(Exception):
     """Class to throw authentication exception."""
 
     @classmethod
@@ -31,5 +32,5 @@ class AbodeAuthenticationException(AbodeException):
         return response.text
 
 
-class SocketIOException(AbodeException):
+class SocketIOException(Exception):
     """Class to throw SocketIO Error exception."""
