@@ -1,5 +1,6 @@
 """Test the Abode device classes."""
 import jaraco.abode
+from jaraco.abode.helpers import urls
 import jaraco.abode.helpers.constants as CONST
 import pytest
 
@@ -19,12 +20,12 @@ class TestAlarm:
         panel = PANEL.get_response_ok(mode=CONST.MODE_STANDBY)
         alarm = ALARM.device(area='1', panel=panel)
 
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.get(CONST.DEVICES_URL, json=DEVICES.EMPTY_DEVICE_RESPONSE)
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.get(urls.DEVICES, json=DEVICES.EMPTY_DEVICE_RESPONSE)
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
-        alarm_device = self.abode.get_alarm()
+        alarm_device = self.client.get_alarm()
 
         assert alarm_device is not None
 
@@ -32,12 +33,12 @@ class TestAlarm:
 
     def tests_alarm_device_properties(self, m):
         """Check that the abode device properties are working."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
         m.get(
-            CONST.PANEL_URL,
+            urls.PANEL,
             json=PANEL.get_response_ok(
                 mode=CONST.MODE_STANDBY,
                 battery=True,
@@ -45,13 +46,13 @@ class TestAlarm:
                 mac='01:AA:b3:C4:d5:66',
             ),
         )
-        m.get(CONST.DEVICES_URL, json=DEVICES.EMPTY_DEVICE_RESPONSE)
+        m.get(urls.DEVICES, json=DEVICES.EMPTY_DEVICE_RESPONSE)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get alarm and test
-        alarm = self.abode.get_alarm()
+        alarm = self.client.get_alarm()
         assert alarm.device_id == 'area_1'
         assert alarm is not None
         assert alarm.mode == CONST.MODE_STANDBY
@@ -64,7 +65,7 @@ class TestAlarm:
 
         # Change alarm properties and state to away and test
         m.get(
-            CONST.PANEL_URL,
+            urls.PANEL,
             json=PANEL.get_response_ok(
                 mode=CONST.MODE_AWAY, battery=False, is_cellular=False
             ),
@@ -81,7 +82,7 @@ class TestAlarm:
         assert alarm.is_on
 
         # Change alarm state to final on state and test
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_HOME))
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_HOME))
 
         # Refresh alarm and test
         alarm.refresh()
@@ -91,33 +92,33 @@ class TestAlarm:
 
     def tests_alarm_device_mode_changes(self, m):
         """Test that the abode alarm can change/report modes."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
-        m.get(CONST.DEVICES_URL, json=DEVICES.EMPTY_DEVICE_RESPONSE)
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        m.get(urls.DEVICES, json=DEVICES.EMPTY_DEVICE_RESPONSE)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Assert that after login we have our alarm device with standby mode
-        alarm = self.abode.get_alarm()
+        alarm = self.client.get_alarm()
 
         assert alarm is not None
         assert alarm.status == CONST.MODE_STANDBY
 
         # Set mode URLs
         m.put(
-            CONST.get_panel_mode_url('1', CONST.MODE_STANDBY),
+            urls.panel_mode('1', CONST.MODE_STANDBY),
             json=PANEL.put_response_ok(mode=CONST.MODE_STANDBY),
         )
         m.put(
-            CONST.get_panel_mode_url('1', CONST.MODE_AWAY),
+            urls.panel_mode('1', CONST.MODE_AWAY),
             json=PANEL.put_response_ok(mode=CONST.MODE_AWAY),
         )
         m.put(
-            CONST.get_panel_mode_url('1', CONST.MODE_HOME),
+            urls.panel_mode('1', CONST.MODE_HOME),
             json=PANEL.put_response_ok(mode=CONST.MODE_HOME),
         )
 
@@ -166,7 +167,7 @@ class TestAlarm:
         assert not alarm.is_home
         assert not alarm.is_away
 
-        self.abode.set_default_mode(CONST.MODE_HOME)
+        self.client.set_default_mode(CONST.MODE_HOME)
         assert alarm.switch_on()
         assert alarm.mode == CONST.MODE_HOME
         assert not alarm.is_standby
@@ -179,7 +180,7 @@ class TestAlarm:
         assert not alarm.is_home
         assert not alarm.is_away
 
-        self.abode.set_default_mode(CONST.MODE_AWAY)
+        self.client.set_default_mode(CONST.MODE_AWAY)
         assert alarm.switch_on()
         assert alarm.mode == CONST.MODE_AWAY
         assert not alarm.is_standby
@@ -187,27 +188,27 @@ class TestAlarm:
         assert alarm.is_away
 
         # Test that no mode throws exception
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             alarm.set_mode(mode=None)
 
         # Test that an invalid mode throws exception
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             alarm.set_mode('chestnuts')
 
         # Test that an invalid mode change response throws exception
         m.put(
-            CONST.get_panel_mode_url('1', CONST.MODE_HOME),
+            urls.panel_mode('1', CONST.MODE_HOME),
             json=PANEL.put_response_ok(mode=CONST.MODE_AWAY),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             alarm.set_mode(CONST.MODE_HOME)
 
         # Test that an invalid area in mode change response throws exception
         m.put(
-            CONST.get_panel_mode_url('1', CONST.MODE_HOME),
+            urls.panel_mode('1', CONST.MODE_HOME),
             json=PANEL.put_response_ok(area='2', mode=CONST.MODE_HOME),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             alarm.set_mode(CONST.MODE_HOME)
