@@ -1,6 +1,6 @@
 """Test the Abode device classes."""
 import jaraco.abode
-import jaraco.abode.helpers.constants as CONST
+from jaraco.abode.helpers import urls
 import pytest
 
 from . import mock as MOCK
@@ -22,23 +22,23 @@ class TestAutomation:
     def tests_automation_init(self, m):
         """Check the Abode automation class init's properly."""
         # Set up URLs
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
         # Set up automation
         automation_resp = AUTOMATION.get_response_ok(
             name='Auto Away', enabled=True, aid=AID_1
         )
 
-        m.get(CONST.AUTOMATION_URL, json=automation_resp)
+        m.get(urls.AUTOMATION, json=automation_resp)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our specific automation
-        automation = self.abode.get_automation(AID_1)
+        automation = self.client.get_automation(AID_1)
 
         # Check automation states match
         assert automation is not None
@@ -51,18 +51,18 @@ class TestAutomation:
 
     def tests_automation_refresh(self, m):
         """Check the automation Abode class refreshes."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
         # Set up automation
         resp = [
             AUTOMATION.get_response_ok(name='Test Automation', enabled=True, aid=AID_1)
         ]
 
-        m.get(CONST.AUTOMATION_URL, json=resp)
+        m.get(urls.AUTOMATION, json=resp)
 
         # Set up refreshed automation
         resp_changed = [
@@ -71,15 +71,15 @@ class TestAutomation:
             )
         ]
 
-        automation_id_url = CONST.AUTOMATION_ID_URL.format(id=resp[0]['id'])
+        automation_id_url = urls.AUTOMATION_ID.format(id=resp[0]['id'])
 
         m.get(automation_id_url, json=resp_changed)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get the first automation and test
-        automation = self.abode.get_automation(AID_1)
+        automation = self.client.get_automation(AID_1)
 
         # Check automation states match
 
@@ -100,7 +100,7 @@ class TestAutomation:
         m.get(automation_id_url, json=resp_changed)
 
         # Refresh and retest
-        automation = self.abode.get_automation(AID_1, refresh=True)
+        automation = self.client.get_automation(AID_1, refresh=True)
 
         assert automation._automation == resp_changed[0]
 
@@ -116,16 +116,16 @@ class TestAutomation:
 
         m.get(automation_id_url, json=resp_changed)
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             automation.refresh()
 
     def tests_multiple_automations(self, m):
         """Check that multiple automations work and return correctly."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
         # Set up automations
         resp = [
@@ -140,36 +140,36 @@ class TestAutomation:
             ),
         ]
 
-        m.get(CONST.AUTOMATION_URL, json=resp)
+        m.get(urls.AUTOMATION, json=resp)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Test that the automations return the correct number
-        automations = self.abode.get_automations()
+        automations = self.client.get_automations()
         assert len(automations) == 3
 
         # Get the first automation and test
 
-        automation_1 = self.abode.get_automation(AID_1)
+        automation_1 = self.client.get_automation(AID_1)
         assert automation_1 is not None
         assert automation_1._automation == resp[0]
 
-        automation_2 = self.abode.get_automation(AID_2)
+        automation_2 = self.client.get_automation(AID_2)
         assert automation_2 is not None
         assert automation_2._automation == resp[1]
 
-        automation_3 = self.abode.get_automation(AID_3)
+        automation_3 = self.client.get_automation(AID_3)
         assert automation_3 is not None
         assert automation_3._automation == resp[2]
 
     def tests_automation_class_reuse(self, m):
         """Check that automations reuse the same classes when refreshed."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
         # Set up automations
         resp = [
@@ -181,22 +181,22 @@ class TestAutomation:
             ),
         ]
 
-        m.get(CONST.AUTOMATION_URL, json=resp)
+        m.get(urls.AUTOMATION, json=resp)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Test that the automations return the correct number
-        automations = self.abode.get_automations()
+        automations = self.client.get_automations()
         assert len(automations) == 2
 
         # Get the automations and test
 
-        automation_1 = self.abode.get_automation(AID_1)
+        automation_1 = self.client.get_automation(AID_1)
         assert automation_1 is not None
         assert automation_1._automation == resp[0]
 
-        automation_2 = self.abode.get_automation(AID_2)
+        automation_2 = self.client.get_automation(AID_2)
         assert automation_2 is not None
         assert automation_2._automation == resp[1]
 
@@ -213,36 +213,36 @@ class TestAutomation:
             ),
         ]
 
-        m.get(CONST.AUTOMATION_URL, json=resp)
+        m.get(urls.AUTOMATION, json=resp)
 
         # Update
-        automations_changed = self.abode.get_automations(refresh=True)
+        automations_changed = self.client.get_automations(refresh=True)
         assert len(automations_changed) == 3
 
         # Check that the original two automations have updated
         # and are using the same class
-        automation_1_changed = self.abode.get_automation(AID_1)
+        automation_1_changed = self.client.get_automation(AID_1)
         assert automation_1_changed is not None
         assert automation_1_changed._automation == resp[0]
         assert automation_1 is automation_1_changed
 
-        automation_2_changed = self.abode.get_automation(AID_2)
+        automation_2_changed = self.client.get_automation(AID_2)
         assert automation_2_changed is not None
         assert automation_2_changed._automation == resp[1]
         assert automation_2 is automation_2_changed
 
         # Check that the third new automation is correct
-        automation_3 = self.abode.get_automation(AID_3)
+        automation_3 = self.client.get_automation(AID_3)
         assert automation_3 is not None
         assert automation_3._automation == resp[2]
 
     def tests_automation_enable(self, m):
         """Check that automations can change their enable state."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
         # Set up automation
         resp = [
@@ -251,20 +251,20 @@ class TestAutomation:
             )
         ]
 
-        m.get(CONST.AUTOMATION_URL, json=resp)
+        m.get(urls.AUTOMATION, json=resp)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get the automation and test
 
-        automation = self.abode.get_automation(AID_1)
+        automation = self.client.get_automation(AID_1)
         assert automation is not None
         assert automation._automation == resp[0]
         assert automation.is_enabled
 
         # Set up our active state change and URL
-        set_active_url = CONST.AUTOMATION_ID_URL.format(id=resp[0]['id'])
+        set_active_url = urls.AUTOMATION_ID.format(id=resp[0]['id'])
 
         m.patch(
             set_active_url,
@@ -301,7 +301,7 @@ class TestAutomation:
             ],
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             automation.enable(False)
 
         # Test that the response returns the wrong id
@@ -314,16 +314,16 @@ class TestAutomation:
             ],
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             automation.enable(True)
 
     def tests_automation_trigger(self, m):
         """Check that automations can be triggered."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
         # Set up automation
         resp = [
@@ -332,18 +332,18 @@ class TestAutomation:
             ),
         ]
 
-        m.get(CONST.AUTOMATION_URL, json=resp)
+        m.get(urls.AUTOMATION, json=resp)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get the automation and test
 
-        automation = self.abode.get_automation(AID_1)
+        automation = self.client.get_automation(AID_1)
         assert automation is not None
 
         # Set up our automation trigger reply
-        set_active_url = CONST.AUTOMATION_APPLY_URL.format(id=automation.automation_id)
+        set_active_url = urls.AUTOMATION_APPLY.format(id=automation.automation_id)
         m.post(set_active_url, json=MOCK.generic_response_ok())
 
         # Test triggering
