@@ -2,6 +2,7 @@
 import functools
 import itertools
 
+from jaraco.abode.helpers import urls
 import jaraco.abode.helpers.constants as CONST
 
 from .mock import login as LOGIN
@@ -22,11 +23,11 @@ class TestBinarySensors:
 
     def tests_binary_sensor_properties(self, m):
         """Tests that binary sensor device properties work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # Set up all Binary Sensor Devices in "off states"
         all_devices = [
@@ -74,13 +75,13 @@ class TestBinarySensors:
             ),
         ]
 
-        m.get(CONST.DEVICES_URL, json=all_devices)
+        m.get(urls.DEVICES, json=all_devices)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Test our devices
-        for device in self.abode.get_devices():
+        for device in self.client.get_devices():
             assert not device.is_on, device.type + " is_on failed"
             assert not device.battery_low, device.type + " battery_low failed"
             assert not device.no_response, device.type + " no_response failed"
@@ -131,10 +132,10 @@ class TestBinarySensors:
             ),
         ]
 
-        m.get(CONST.DEVICES_URL, json=all_devices)
+        m.get(urls.DEVICES, json=all_devices)
 
         # Refesh devices and test changes
-        for device in skip_alarms(self.abode.get_devices(refresh=True)):
+        for device in skip_alarms(self.client.get_devices(refresh=True)):
             assert device.is_on, device.type + " is_on failed"
             assert device.battery_low, device.type + " battery_low failed"
             assert device.no_response, device.type + " no_response failed"
