@@ -2,13 +2,8 @@
 import pytest
 
 import jaraco.abode
-from jaraco.abode.devices import AbodeDevice
-from jaraco.abode.devices.alarm import AbodeAlarm
-from jaraco.abode.devices.binary_sensor import AbodeBinarySensor
-from jaraco.abode.devices.cover import AbodeCover
-from jaraco.abode.devices.light import AbodeLight
-from jaraco.abode.devices.lock import AbodeLock
-from jaraco.abode.devices.switch import AbodeSwitch
+from jaraco.abode.helpers import urls
+from jaraco.abode.devices.base import Device
 import jaraco.abode.helpers.constants as CONST
 from .mock import devices as DEVICES
 from .mock.devices import door_contact as DOOR_CONTACT
@@ -34,9 +29,8 @@ from .mock import panel as PANEL
 class TestDevice:
     """Test the generic device class."""
 
-    def tests_device_mapping_typetag(self):
-        """Check the generic Abode device maps to none without typetag."""
-        # Set up device
+    def tests_device_mapping_type_tag(self):
+        """Check new device without type_tag raises exception."""
         device = GLASS.device(
             status=CONST.STATUS_ONLINE,
             low_battery=True,
@@ -45,21 +39,12 @@ class TestDevice:
             out_of_order=True,
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
-            device['type_tag'] = ""
-            jaraco.abode.new_device(device, self.abode)
-
-        with pytest.raises(jaraco.abode.AbodeException):
-            device['type_tag'] = None
-            jaraco.abode.new_device(device, self.abode)
-
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             del device['type_tag']
-            jaraco.abode.new_device(device, self.abode)
+            Device.new(device, self.client)
 
     def tests_device_auto_naming(self):
         """Check the generic Abode device creates a name."""
-        # Set up device
         source = GLASS.device(
             status=CONST.STATUS_ONLINE,
             low_battery=True,
@@ -69,27 +54,27 @@ class TestDevice:
         )
 
         source['name'] = ""
-        device = jaraco.abode.new_device(source, self.abode)
+        device = Device.new(source, self.client)
         generated_name = device.type + ' ' + device.device_id
         assert device.name == generated_name
 
         source['name'] = None
-        device = jaraco.abode.new_device(source, self.abode)
+        device = Device.new(source, self.client)
         generated_name = device.type + ' ' + device.device_id
         assert device.name == generated_name
 
         del source['name']
-        device = jaraco.abode.new_device(source, self.abode)
+        device = Device.new(source, self.client)
         generated_name = device.type + ' ' + device.device_id
         assert device.name == generated_name
 
     def tests_device_init(self, m):
         """Check the generic Abode device class init's properly."""
         # Set up URLs
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
         # Set up device
         source = [
@@ -103,13 +88,13 @@ class TestDevice:
             )
         ]
 
-        m.get(CONST.DEVICES_URL, json=source)
+        m.get(urls.DEVICES, json=source)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our specific device
-        device = self.abode.get_device(GLASS.DEVICE_ID)
+        device = self.client.get_device(GLASS.DEVICE_ID)
 
         # Check device states match
         assert device is not None
@@ -128,37 +113,37 @@ class TestDevice:
 
     def tests_generic_device_refresh(self, m):
         """Check the generic Abode device class init's properly."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
         # Set up online device
-        m.get(CONST.DEVICES_URL, json=[GLASS.device(status=CONST.STATUS_ONLINE)])
+        m.get(urls.DEVICES, json=[GLASS.device(status=CONST.STATUS_ONLINE)])
 
         # Set up offline device
-        device_url = CONST.DEVICE_URL.format(device_id=GLASS.DEVICE_ID)
+        device_url = urls.DEVICE.format(device_id=GLASS.DEVICE_ID)
         m.get(device_url, json=[GLASS.device(status=CONST.STATUS_OFFLINE)])
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get the first device and test
-        device = self.abode.get_device(GLASS.DEVICE_ID)
+        device = self.client.get_device(GLASS.DEVICE_ID)
         assert device.status == CONST.STATUS_ONLINE
 
         # Refresh the device and test
-        device = self.abode.get_device(GLASS.DEVICE_ID, refresh=True)
+        device = self.client.get_device(GLASS.DEVICE_ID, refresh=True)
         assert device.status == CONST.STATUS_OFFLINE
 
     def tests_multiple_devices(self, m):
         """Tests that multiple devices are returned properly."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # Set up a list of devices
         dev_list = [
@@ -167,45 +152,45 @@ class TestDevice:
             GLASS.device(),
         ]
 
-        m.get(CONST.DEVICES_URL, json=dev_list)
+        m.get(urls.DEVICES, json=dev_list)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our devices
-        devices = self.abode.get_devices()
+        devices = self.client.get_devices()
 
         # Assert four devices - three from above + 1 alarm
         assert devices is not None
         assert len(devices) == 4
 
         # Get each individual device by device ID
-        psd = self.abode.get_device(POWERSENSOR.DEVICE_ID)
+        psd = self.client.get_device(POWERSENSOR.DEVICE_ID)
         assert psd is not None
 
         # Get each individual device by device ID
-        psd = self.abode.get_device(DOOR_CONTACT.DEVICE_ID)
+        psd = self.client.get_device(DOOR_CONTACT.DEVICE_ID)
         assert psd is not None
 
         # Get each individual device by device ID
-        psd = self.abode.get_device(GLASS.DEVICE_ID)
+        psd = self.client.get_device(GLASS.DEVICE_ID)
         assert psd is not None
 
     def tests_unknown_devices(self, m):
         """Tests that multiple devices are returned properly."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
-        m.get(CONST.DEVICES_URL, json=[UNKNOWN.device()])
+        m.get(urls.DEVICES, json=[UNKNOWN.device()])
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our devices
-        devices = self.abode.get_devices()
+        devices = self.client.get_devices()
 
         # Assert 1 device - skipped device above + 1 alarm
         assert devices is not None
@@ -213,11 +198,11 @@ class TestDevice:
 
     def tests_device_category_filter(self, m):
         """Tests that device category filter returns requested results."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # Set up a list of devices
         dev_list = [
@@ -241,38 +226,38 @@ class TestDevice:
             ),
         ]
 
-        m.get(CONST.DEVICES_URL, json=dev_list)
+        m.get(urls.DEVICES, json=dev_list)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our glass devices
-        devices = self.abode.get_devices(generic_type=CONST.TYPE_CONNECTIVITY)
+        devices = self.client.get_devices(generic_type=CONST.TYPE_CONNECTIVITY)
 
         assert devices is not None
         assert len(devices) == 1
 
         # Get our power switch devices
-        devices = self.abode.get_devices(generic_type=CONST.TYPE_SWITCH)
+        devices = self.client.get_devices(generic_type=CONST.TYPE_SWITCH)
 
         assert devices is not None
         assert len(devices) == 2
 
     def tests_no_control_url(self, m):
         """Check that devices return false without control url's."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok())
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok())
 
-        m.get(CONST.DEVICES_URL, json=GLASS.device(status=CONST.STATUS_ONLINE))
+        m.get(urls.DEVICES, json=GLASS.device(status=CONST.STATUS_ONLINE))
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get device
-        device = self.abode.get_device(GLASS.DEVICE_ID)
+        device = self.client.get_device(GLASS.DEVICE_ID)
 
         assert device is not None
         assert not device.set_status('1')
@@ -280,13 +265,13 @@ class TestDevice:
 
     def tests_device_status_changes(self, m):
         """Tests that device status changes work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=POWERSENSOR.device(
                 devid=POWERSENSOR.DEVICE_ID,
                 status=CONST.STATUS_OFF,
@@ -296,10 +281,10 @@ class TestDevice:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our power switch
-        device = self.abode.get_device(POWERSENSOR.DEVICE_ID)
+        device = self.client.get_device(POWERSENSOR.DEVICE_ID)
 
         # Test that we have our device
         assert device is not None
@@ -341,7 +326,7 @@ class TestDevice:
             ),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.switch_on()
 
         # Test that an invalid status in response throws exception
@@ -352,20 +337,20 @@ class TestDevice:
             ),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.switch_on()
 
     def tests_device_level_changes(self, m):
         """Tests that device level changes work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # TODO: Test with a device that supports levels
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=POWERSENSOR.device(
                 devid=POWERSENSOR.DEVICE_ID,
                 status=CONST.STATUS_OFF,
@@ -375,10 +360,10 @@ class TestDevice:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our power switch
-        device = self.abode.get_device(POWERSENSOR.DEVICE_ID)
+        device = self.client.get_device(POWERSENSOR.DEVICE_ID)
 
         # Test that we have our device
         assert device is not None
@@ -413,7 +398,7 @@ class TestDevice:
             json=DEVICES.level_put_response_ok(devid='ZW:deadbeef', level='25'),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.set_level(25)
 
         # Test that an invalid level in response throws exception
@@ -422,16 +407,16 @@ class TestDevice:
             json=DEVICES.level_put_response_ok(devid=POWERSENSOR.DEVICE_ID, level='98'),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.set_level('28')
 
     def tests_all_devices(self, m):
         """Tests that all mocked devices are mapped correctly."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
 
         # Create all devices
         all_devices = [
@@ -450,39 +435,14 @@ class TestDevice:
             WATER_SENSOR.device(),
         ]
 
-        m.get(CONST.DEVICES_URL, json=all_devices)
+        m.get(urls.DEVICES, json=all_devices)
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Loop through all devices
-        for device in self.abode.get_devices():
-            class_type = {
-                # Alarm
-                CONST.TYPE_ALARM: AbodeAlarm,
-                # Binary Sensors
-                CONST.TYPE_CONNECTIVITY: AbodeBinarySensor,
-                CONST.TYPE_MOISTURE: AbodeBinarySensor,
-                CONST.TYPE_OPENING: AbodeBinarySensor,
-                CONST.TYPE_MOTION: AbodeBinarySensor,
-                CONST.TYPE_OCCUPANCY: AbodeBinarySensor,
-                # Camera
-                CONST.TYPE_CAMERA: AbodeDevice,
-                # Cover
-                CONST.TYPE_COVER: AbodeCover,
-                # Dimmer
-                CONST.TYPE_LIGHT: AbodeLight,
-                # Lock
-                CONST.TYPE_LOCK: AbodeLock,
-                # Switch
-                CONST.TYPE_SWITCH: AbodeSwitch,
-            }.get(device.generic_type)
+        for device in self.client.get_devices():
+            class_type = Device.by_type().get(device.generic_type)
 
             assert class_type is not None, device.type + ' is not mapped.'
-            assert isinstance(device, class_type), (
-                device.type
-                + ' is of class '
-                + str(device.__class__.__name__)
-                + ' but mapped to '
-                + str(class_type.__name__)
-            )
+            assert isinstance(device, class_type)
