@@ -1,6 +1,7 @@
 """Test the Abode device classes."""
 
 import jaraco.abode
+from jaraco.abode.helpers import urls
 import jaraco.abode.helpers.constants as CONST
 
 import pytest
@@ -18,13 +19,13 @@ class TestDoorLock:
 
     def tests_lock_device_properties(self, m):
         """Tests that lock devices properties work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=DOOR_LOCK.device(
                 devid=DOOR_LOCK.DEVICE_ID,
                 status=CONST.STATUS_LOCKCLOSED,
@@ -34,10 +35,10 @@ class TestDoorLock:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our lock
-        device = self.abode.get_device(DOOR_LOCK.DEVICE_ID)
+        device = self.client.get_device(DOOR_LOCK.DEVICE_ID)
 
         # Test our device
         assert device is not None
@@ -47,7 +48,7 @@ class TestDoorLock:
         assert device.is_locked
 
         # Set up our direct device get url
-        device_url = CONST.DEVICE_URL.format(device_id=DOOR_LOCK.DEVICE_ID)
+        device_url = urls.DEVICE.format(device_id=DOOR_LOCK.DEVICE_ID)
 
         # Change device properties
         m.get(
@@ -70,13 +71,13 @@ class TestDoorLock:
 
     def tests_lock_device_mode_changes(self, m):
         """Tests that lock device changes work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=DOOR_LOCK.device(
                 devid=DOOR_LOCK.DEVICE_ID,
                 status=CONST.STATUS_LOCKCLOSED,
@@ -86,10 +87,10 @@ class TestDoorLock:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our power switch
-        device = self.abode.get_device(DOOR_LOCK.DEVICE_ID)
+        device = self.client.get_device(DOOR_LOCK.DEVICE_ID)
 
         # Test that we have our device
         assert device is not None
@@ -97,7 +98,7 @@ class TestDoorLock:
         assert device.is_locked
 
         # Set up control url response
-        control_url = CONST.BASE_URL + DOOR_LOCK.CONTROL_URL
+        control_url = urls.BASE + DOOR_LOCK.CONTROL_URL
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
@@ -131,5 +132,5 @@ class TestDoorLock:
             ),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.unlock()
