@@ -4,9 +4,10 @@ from unittest.mock import call, Mock
 import pytest
 
 import jaraco.abode
+from jaraco.abode.helpers import urls
 import jaraco.abode.helpers.constants as CONST
 import jaraco.abode.helpers.timeline as TIMELINE
-from jaraco.abode.devices.binary_sensor import AbodeBinarySensor
+from jaraco.abode.devices.binary_sensor import BinarySensor
 
 from .mock import login as LOGIN
 from .mock import oauth_claims as OAUTH_CLAIMS
@@ -22,13 +23,13 @@ class TestEventController:
 
     def tests_device_id_registration(self, m):
         """Tests that we can register for device events with a device id."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -38,14 +39,14 @@ class TestEventController:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our device
-        device = self.abode.get_device(COVER.DEVICE_ID)
+        device = self.client.get_device(COVER.DEVICE_ID)
         assert device is not None
 
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callback
@@ -56,13 +57,13 @@ class TestEventController:
 
     def tests_device_registration(self, m):
         """Tests that we can register for device events with a device."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -72,14 +73,14 @@ class TestEventController:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our device
-        device = self.abode.get_device(COVER.DEVICE_ID)
+        device = self.client.get_device(COVER.DEVICE_ID)
         assert device is not None
 
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Register our device
@@ -87,13 +88,13 @@ class TestEventController:
 
     def tests_device_all_unregistration(self, m):
         """Tests that we can unregister for all device events."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -103,14 +104,14 @@ class TestEventController:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our device
-        device = self.abode.get_device(COVER.DEVICE_ID)
+        device = self.client.get_device(COVER.DEVICE_ID)
         assert device is not None
 
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Register our device
@@ -121,13 +122,13 @@ class TestEventController:
 
     def tests_invalid_device(self, m):
         """Tests that invalid devices are not registered."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -137,14 +138,14 @@ class TestEventController:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our device
-        device = self.abode.get_device(COVER.DEVICE_ID)
+        device = self.client.get_device(COVER.DEVICE_ID)
         assert device is not None
 
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callback
@@ -154,20 +155,20 @@ class TestEventController:
         assert not events.add_device_callback(None, callback)
 
         # Create a fake device and attempt to register that
-        fake_device = AbodeBinarySensor(DOORCONTACT.device(), self.abode)
+        fake_device = BinarySensor(DOORCONTACT.device(), self.client)
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             events.add_device_callback(fake_device, callback)
 
     def tests_invalid_all_device_unregister(self, m):
         """Tests that invalid devices are not all unregistered."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -177,29 +178,29 @@ class TestEventController:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our device
-        device = self.abode.get_device(COVER.DEVICE_ID)
+        device = self.client.get_device(COVER.DEVICE_ID)
         assert device is not None
 
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Test that no device returns false
         assert not events.remove_all_device_callbacks(None)
 
         # Create a fake device and attempt to unregister that
-        fake_device = AbodeBinarySensor(DOORCONTACT.device(), self.abode)
+        fake_device = BinarySensor(DOORCONTACT.device(), self.client)
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             events.remove_all_device_callbacks(fake_device)
 
     def tests_event_registration(self):
         """Tests that events register correctly."""
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callback
@@ -212,13 +213,13 @@ class TestEventController:
         assert not events.add_event_callback(None, callback)
 
         # Test that an invalid event throws exception
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             events.add_event_callback("lol", callback)
 
     def tests_timeline_registration(self):
         """Tests that timeline events register correctly."""
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callback
@@ -231,22 +232,22 @@ class TestEventController:
         assert not events.add_timeline_callback(None, callback)
 
         # Test that an invalid timeline event string throws exception
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             events.add_timeline_callback("lol", callback)
 
         # Test that an invalid timeline event dict throws exception
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             events.add_timeline_callback({"lol": "lol"}, callback)
 
     def tests_device_callback(self, m):
         """Tests that device updates callback correctly."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -256,14 +257,14 @@ class TestEventController:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our device
-        device = self.abode.get_device(COVER.DEVICE_ID)
+        device = self.client.get_device(COVER.DEVICE_ID)
         assert device is not None
 
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         callback = Mock()
@@ -272,7 +273,7 @@ class TestEventController:
         assert events.add_device_callback(device.device_id, callback)
 
         # Set up device update URL
-        device_url = CONST.DEVICE_URL.format(device_id=COVER.DEVICE_ID)
+        device_url = urls.DEVICE.format(device_id=COVER.DEVICE_ID)
         m.get(
             device_url,
             json=COVER.device(
@@ -300,7 +301,7 @@ class TestEventController:
     def tests_events_callback(self):
         """Tests that event updates callback correctly."""
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callbacks
@@ -327,7 +328,7 @@ class TestEventController:
     def tests_timeline_callback(self):
         """Tests that timeline updates callback correctly."""
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callbacks
@@ -357,13 +358,13 @@ class TestEventController:
 
     def tests_alarm_callback(self, m):
         """Tests that alarm device updates callback correctly."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=COVER.device(
                 devid=COVER.DEVICE_ID,
                 status=CONST.STATUS_CLOSED,
@@ -373,14 +374,14 @@ class TestEventController:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our alarm device
-        alarm = self.abode.get_alarm()
+        alarm = self.client.get_alarm()
         assert alarm is not None
 
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         callback = Mock()
@@ -405,7 +406,7 @@ class TestEventController:
     def tests_execute_callback(self):
         """Tests that callbacks that throw exceptions don't bomb."""
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create callbacks
@@ -422,13 +423,13 @@ class TestEventController:
 
     def tests_multi_device_callback(self, m):
         """Tests that multiple device updates callback correctly."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=[
                 COVER.device(
                     devid=COVER.DEVICE_ID,
@@ -443,17 +444,17 @@ class TestEventController:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our devices
-        cover = self.abode.get_device(COVER.DEVICE_ID)
+        cover = self.client.get_device(COVER.DEVICE_ID)
         assert cover is not None
 
-        doorcontact = self.abode.get_device(DOORCONTACT.DEVICE_ID)
+        doorcontact = self.client.get_device(DOORCONTACT.DEVICE_ID)
         assert doorcontact is not None
 
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         callback = Mock()
@@ -461,8 +462,8 @@ class TestEventController:
         # Register our devices
         assert events.add_device_callback([cover, doorcontact], callback)
 
-        # Set up device update URL's
-        cover_url = CONST.DEVICE_URL.format(device_id=COVER.DEVICE_ID)
+        # Set up device update URLs
+        cover_url = urls.DEVICE.format(device_id=COVER.DEVICE_ID)
         m.get(
             cover_url,
             json=COVER.device(
@@ -473,7 +474,7 @@ class TestEventController:
             ),
         )
 
-        door_url = CONST.DEVICE_URL.format(device_id=DOORCONTACT.DEVICE_ID)
+        door_url = urls.DEVICE.format(device_id=DOORCONTACT.DEVICE_ID)
         m.get(
             door_url,
             json=DOORCONTACT.device(devid=COVER.DEVICE_ID, status=CONST.STATUS_OPEN),
@@ -500,7 +501,7 @@ class TestEventController:
     def tests_multi_events_callback(self):
         """Tests that multiple event updates callback correctly."""
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callback
@@ -522,7 +523,7 @@ class TestEventController:
     def tests_multi_timeline_callback(self):
         """Tests that multiple timeline updates callback correctly."""
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callback
@@ -544,7 +545,7 @@ class TestEventController:
     def tests_automations_callback(self):
         """Tests that automation updates callback correctly."""
         # Get the event controller
-        events = self.abode.events
+        events = self.client.events
         assert events is not None
 
         # Create mock callbacks
