@@ -3,6 +3,7 @@
 import pytest
 
 import jaraco.abode
+from jaraco.abode.helpers import urls
 import jaraco.abode.helpers.constants as CONST
 
 from .mock import login as LOGIN
@@ -18,13 +19,13 @@ class TestHue:
 
     def tests_hue_device_properties(self, m):
         """Tests that hue light devices properties work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=HUE.device(
                 devid=HUE.DEVICE_ID,
                 status=CONST.STATUS_OFF,
@@ -39,10 +40,10 @@ class TestHue:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our dimmer
-        device = self.abode.get_device(HUE.DEVICE_ID)
+        device = self.client.get_device(HUE.DEVICE_ID)
 
         # Test our device
         assert device is not None
@@ -59,7 +60,7 @@ class TestHue:
         assert not device.is_on
 
         # Set up our direct device get url
-        device_url = CONST.DEVICE_URL.format(device_id=HUE.DEVICE_ID)
+        device_url = urls.DEVICE.format(device_id=HUE.DEVICE_ID)
 
         # Change device properties
         m.get(
@@ -93,13 +94,13 @@ class TestHue:
 
     def tests_hue_status_changes(self, m):
         """Tests that hue device changes work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=HUE.device(
                 devid=HUE.DEVICE_ID,
                 status=CONST.STATUS_OFF,
@@ -114,10 +115,10 @@ class TestHue:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our hue device
-        device = self.abode.get_device(HUE.DEVICE_ID)
+        device = self.client.get_device(HUE.DEVICE_ID)
 
         # Test that we have our device
         assert device is not None
@@ -125,7 +126,7 @@ class TestHue:
         assert not device.is_on
 
         # Set up control url response
-        control_url = CONST.BASE_URL + HUE.CONTROL_URL
+        control_url = urls.BASE + HUE.CONTROL_URL
         m.put(
             control_url,
             json=DEVICES.status_put_response_ok(
@@ -159,18 +160,18 @@ class TestHue:
             ),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.switch_on()
 
     def tests_hue_color_temp_changes(self, m):
         """Tests that hue device color temp changes work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=HUE.device(
                 devid=HUE.DEVICE_ID,
                 status=CONST.STATUS_OFF,
@@ -185,10 +186,10 @@ class TestHue:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our hue device
-        device = self.abode.get_device(HUE.DEVICE_ID)
+        device = self.client.get_device(HUE.DEVICE_ID)
 
         # Test that we have our device
         assert device is not None
@@ -226,18 +227,18 @@ class TestHue:
             ),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.set_color_temp(4434)
 
     def tests_hue_color_changes(self, m):
         """Tests that hue device color changes work as expected."""
-        # Set up URL's
-        m.post(CONST.LOGIN_URL, json=LOGIN.post_response_ok())
-        m.get(CONST.OAUTH_TOKEN_URL, json=OAUTH_CLAIMS.get_response_ok())
-        m.post(CONST.LOGOUT_URL, json=LOGOUT.post_response_ok())
-        m.get(CONST.PANEL_URL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
+        # Set up URLs
+        m.post(urls.LOGIN, json=LOGIN.post_response_ok())
+        m.get(urls.OAUTH_TOKEN, json=OAUTH_CLAIMS.get_response_ok())
+        m.post(urls.LOGOUT, json=LOGOUT.post_response_ok())
+        m.get(urls.PANEL, json=PANEL.get_response_ok(mode=CONST.MODE_STANDBY))
         m.get(
-            CONST.DEVICES_URL,
+            urls.DEVICES,
             json=HUE.device(
                 devid=HUE.DEVICE_ID,
                 status=CONST.STATUS_OFF,
@@ -252,10 +253,10 @@ class TestHue:
         )
 
         # Logout to reset everything
-        self.abode.logout()
+        self.client.logout()
 
         # Get our hue device
-        device = self.abode.get_device(HUE.DEVICE_ID)
+        device = self.client.get_device(HUE.DEVICE_ID)
 
         # Test that we have our device
         assert device is not None
@@ -293,5 +294,5 @@ class TestHue:
             ),
         )
 
-        with pytest.raises(jaraco.abode.AbodeException):
+        with pytest.raises(jaraco.abode.Exception):
             device.set_color((44, 44))
